@@ -19,7 +19,7 @@
 }  
 #------------------------------------------------------------------------------
 # Julious "expected" power
-exppower.TOST <- function(alpha=0.05, theta1=0.8, theta2, theta0=0.95,
+exppower.TOST <- function(alpha=0.05, logscale=TRUE, theta0, theta1, theta2, 
                           CV, dfCV, n, design="2x2", robust=FALSE)
 {
   # check if design is implemented
@@ -41,14 +41,29 @@ exppower.TOST <- function(alpha=0.05, theta1=0.8, theta2, theta0=0.95,
   if (missing(CV) | missing(dfCV)) stop("CV and df must be given!", call.=FALSE)
   if (missing(n)) stop("Number of subjects must be given!", call.=FALSE)
   
-  if (missing(theta2)) theta2 <- 1/theta1
-  
-  ltheta1 <- log(theta1)
-  ltheta2 <- log(theta2)
-  ldiff   <- log(theta0)
-  se      <- CV2se(CV)
+  if (logscale) {
+    if (missing(theta0)) theta0 <- 0.95
+    if (missing(theta1)) theta1 <- 0.8 
+    if (missing(theta2)) theta2 <- 1/theta1
+    
+    ltheta1 <- log(theta1)
+    ltheta2 <- log(theta2)
+    ldiff   <- log(theta0)
+    se      <- CV2se(CV)
+    
+  } else {
+    if (missing(theta0)) theta0 <- 0.05
+    if (missing(theta1)) theta1 <- -0.2 
+    if (missing(theta2)) theta2 <- -theta1
+    ltheta1 <- theta1
+    ltheta2 <- theta2
+    ldiff   <- theta0
+    se      <- CV
+  }
+
   df      <- eval(dfe)
-  if (df<1) stop("n too low. Degrees of freedom <1!", call.=FALSE)
+  if (any(df<1)) stop("n too low. Degrees of freedom <1!", call.=FALSE)
+  
   pow <- .exppower.TOST(alpha, ltheta1, ltheta2, ldiff, se, dfCV, n, df, bk)
   
   return( pow )
